@@ -41,21 +41,3 @@ rlang::`:=`
 #' @export
 #' @importFrom zeallot "%<-%"
 zeallot::`%<-%`
-
-# ----------------------- crayon -------------------------------------
-
-#' @export
-#' @importFrom crayon blue
-crayon::blue
-
-#' @export
-#' @importFrom crayon green
-crayon::green
-
-#' @export
-#' @importFrom crayon red
-crayon::red
-
-#' @export
-#' @importFrom crayon yellow
-crayon::yellow
